@@ -3,7 +3,7 @@
 """pandoc-tablenos: a pandoc filter that inserts table nos. and refs."""
 
 
-__version__ = '2.2.0'
+__version__ = '2.2.2'
 
 
 # Copyright 2015-2020 Thomas J. Duck.
@@ -54,11 +54,11 @@ from pandocfilters import Table, Str, Space, RawBlock, RawInline, Math, Span
 import pandocxnos
 from pandocxnos import PandocAttributes
 from pandocxnos import STRTYPES, STDIN, STDOUT, STDERR
-from pandocxnos import check_bool, get_meta, extract_attrs
+from pandocxnos import NBSP
+from pandocxnos import elt, check_bool, get_meta, extract_attrs
 from pandocxnos import repair_refs, process_refs_factory, replace_refs_factory
 from pandocxnos import insert_secnos_factory, delete_secnos_factory
 from pandocxnos import attach_attrs_factory, detach_attrs_factory
-from pandocxnos import elt
 from pandocxnos import version
 
 
@@ -112,8 +112,11 @@ def attach_attrs_table(key, value, fmt, meta):
         else:
             assert len(value) == 6
             assert value[1]['t'] == 'Caption'
-            assert value[1]['c'][1][0]['t'] == 'Plain'
-            caption = value[1]['c'][1][0]['c']
+            if value[1]['c'][1]:
+                assert value[1]['c'][1][0]['t'] == 'Plain'
+                caption = value[1]['c'][1][0]['c']
+            else:
+                return  # There is no caption
 
         # Set n to the index where the attributes start
         n = 0
@@ -158,7 +161,10 @@ def _process_table(value, fmt):
     if version(PANDOCVERSION) < version('2.10'):
         table['caption'] = value[1]
     else:
-        table['caption'] = value[1]['c'][1][0]['c']
+        if value[1]['c'][1]:
+            table['caption'] = value[1]['c'][1][0]['c']
+        else:
+            table['caption'] = []
 
     # Bail out if the label does not conform to expectations
     if not LABEL_PATTERN.match(attrs.id):
@@ -226,24 +232,18 @@ def _adjust_caption(fmt, table, value):
         if isinstance(num, int):  # Numbered reference
             if fmt in ['html', 'html4', 'html5', 'epub', 'epub2', 'epub3']:
                 tmp = [RawInline('html', r'<span>'),
-                       Str(captionname), Space(),
-                       Str('%d%s'%(num, sep)),
+                       Str(captionname+NBSP), Str('%d%s'%(num, sep)),
                        RawInline('html', r'</span>')]
                 if version(PANDOCVERSION) < version('2.10'):
                     value[1] = tmp
                 else:
                     value[1]['c'][1][0]['c'] = tmp
             else:
-                tmp = [Str(captionname), Space(), Str('%d%s'%(num, sep))]
+                tmp = [Str(captionname+NBSP), Str('%d%s'%(num, sep))]
                 if version(PANDOCVERSION) < version('2.10'):
                     value[1] = tmp
                 else:
                     value[1]['c'][1][0]['c'] = tmp
-            tmp = [Space()] + list(caption)
-            if version(PANDOCVERSION) <= version('2.10'):
-                value[1] += tmp
-            else:
-                value[1]['c'][1][0]['c'] += tmp
         else:  # Tagged reference
             assert isinstance(num, STRTYPES)
             if num.startswith('$') and num.endswith('$'):
@@ -253,23 +253,23 @@ def _adjust_caption(fmt, table, value):
                 els = [Str(num + sep)]
             if fmt in ['html', 'html4', 'html5', 'epub', 'epub2', 'epub3']:
                 tmp = [RawInline('html', r'<span>'),
-                       Str(captionname),
-                       Space()] + els + [RawInline('html', r'</span>')]
+                       Str(captionname+NBSP)] + \
+                      els + [RawInline('html', r'</span>')]
                 if version(PANDOCVERSION) < version('2.10'):
                     value[1] = tmp
                 else:
                     value[1]['c'][1][0]['c'] = tmp
             else:
-                tmp = [Str(captionname), Space()] + els
+                tmp = [Str(captionname+NBSP)] + els
                 if version(PANDOCVERSION) < version('2.10'):
                     value[1] = tmp
                 else:
                     value[1]['c'][1][0]['c'] = tmp
-            tmp = [Space()] + list(caption)
-            if version(PANDOCVERSION) <= version('2.10'):
-                value[1] += tmp
-            else:
-                value[1]['c'][1][0]['c'] += tmp
+        tmp = [Space()] + list(caption)
+        if version(PANDOCVERSION) < version('2.10'):
+            value[1] += tmp
+        else:
+            value[1]['c'][1][0]['c'] += tmp
 
 def _add_markup(fmt, table, value):
     """Adds markup to the output."""
